==> kvirc_2.1.3.orig.tar.gz: kvirc-2.1.3/src/plugins/mydialog/kvi_mydialog.cpp <==
// =============================================================================
//
//   This is a "ready to edit" source for your first plugin
//   Copyright (C) 1999-2000 PLACE YOUR NAME HERE (your@email)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#define _KVI_DEBUG_CHECK_RANGE_
#define _KVI_DEBUG_CLASS_NAME_ "KviMyDialog"

#include <qlayout.h>

#define __KVIRC_PLUGIN__

#include "kvi_lineedit.h"
#include "kvi_mydialog.h"
#include "kvi_pushbutton.h"

/**
 * This is the constructor for the simple dialog
 */
MyDialog::MyDialog(KviPluginCommandStruct *kcmd)
	: KviDialog(0, "mydialog")
{
	setCaption("MyDialog");
	m_pWin = kcmd->window;
	QGridLayout *g = new QGridLayout(this, 4, 2);
	m_pE1 = new KviLineEdit(this);
	m_pE2 = new KviLineEdit(this);
	m_pE3 = new KviLineEdit(this);
	g->addMultiCellWidget(m_pE1, 0, 0, 0, 1);
	g->addMultiCellWidget(m_pE2, 1, 1, 0, 1);
	g->addMultiCellWidget(m_pE3, 2, 2, 0, 1);

	KviPushButton *b;
	b = new KviPushButton("test", this, "mydialog_testbutton");
	connect(b, SIGNAL(clicked()), this, SLOT(btn_pressed()));
	g->addWidget(b, 3, 0);

	b = new KviPushButton("btn2", this, "mydialog_testbutton");
	connect(b, SIGNAL(clicked()), this, SLOT(btn2_pressed()));
	g->addWidget(b, 3, 1);
}

void MyDialog::btn_pressed()
{
	m_pWin->output(KVI_OUT_INTERNAL, "MYDIALOG: test");
	m_pWin->output(KVI_OUT_INTERNAL, m_pE1->text().latin1());
	m_pWin->output(KVI_OUT_INTERNAL, m_pE2->text().latin1());
	m_pWin->output(KVI_OUT_INTERNAL, m_pE3->text().latin1());
}

void MyDialog::btn2_pressed()
{
	m_pWin->output(KVI_OUT_INTERNAL, "MYDIALOG: button 2");
	m_pWin->output(KVI_OUT_INTERNAL, m_pE1->text().latin1());
	m_pWin->output(KVI_OUT_INTERNAL, m_pE2->text().latin1());
	m_pWin->output(KVI_OUT_INTERNAL, m_pE3->text().latin1());
}

MyDialog::~MyDialog()
{
}

/**
 * This is a global in the plugin.
 */
MyDialog *d = 0;

/**
 * This is what the command MYDIALOG does.
 */
bool mydialog_plugin_command_mydialog(KviPluginCommandStruct *cmd)
{
	if( !d ) d = new MyDialog(cmd);
	d->show();
	return true;
}

/**
 * Init routine: registers the command MYDIALOG.
 */
bool mydialog_plugin_init(KviPluginCommandStruct *cmd)
{
	kvirc_plugin_register_command(cmd->handle, "MYDIALOG", mydialog_plugin_command_mydialog);
	return true;
}

/**
 * Cleanup routine: do not forget to delete the objects you have created :)
 */
void mydialog_plugin_cleanup()
{
	if( d ) {
		delete d;
		d = 0;
	}
}

/**
	@document: doc_plugin_mydialog.kvihelp
	@title: The KVIrc MyDialog plugin
		This plugin is for demonstration only. Its purpose is to show how to implement
		dialogs in plugins.<br>
		<docsubtitle>Note</docsubtitle>
		...<br>
		...<br>
		...<br>
*/

/**
 * Tells KVIrc where to find the help page.
 */
void mydialog_plugin_help()
{
	kvirc_plugin_show_help_page("doc_plugin_mydialog.kvihelp");
}

/**
 * Your plugin definition structure
 */
KviPlugin kvirc_plugin =
{
	"MyDialog",                             // Place the name of your plugin here. It should be the same as the library name.
	"My first KVIrc plugin (dialog)",       // Place a one line description of your plugin here.
	"0.1",                                  // Place the version of your plugin here.
	"Your Name <you@mailhost>",             // Place your name and email here.
	"<html>"
		"This plugin shows you how to use "
		"Qt dialogs in plugins...<br>"
		"It exports the <b>/MYDIALOG</b> command."
		"</html>",                          // Place a short description of what your plugin does here.
	mydialog_plugin_init,                   // Init routine
	mydialog_plugin_cleanup,                // Cleanup routine
	0,                                      // You have no configuration routine yet
	mydialog_plugin_help                    // This is the way to provide help for you plugin
};

#include "m_kvi_mydialog.moc"

==> kvirc2_2.1.3.orig.tar.gz: kvirc2-2.1.3/src/plugins/mydialog/kvi_mydialog.cpp <==
// =============================================================================
//
//   This is a "ready to edit" source for your first plugin
//   Copyright (C) 1999-2000 PLACE YOUR NAME HERE (your@email)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#define _KVI_DEBUG_CHECK_RANGE_
#define _KVI_DEBUG_CLASS_NAME_ "KviMyDialog"

#include <qlayout.h>

#define __KVIRC_PLUGIN__

#include "kvi_lineedit.h"
#include "kvi_mydialog.h"
#include "kvi_pushbutton.h"

/**
 * This is the constructor for the simple dialog
 */
MyDialog::MyDialog(KviPluginCommandStruct *kcmd)
	: KviDialog(0, "mydialog")
{
	setCaption("MyDialog");
	m_pWin = kcmd->window;
	QGridLayout *g = new QGridLayout(this, 4, 2);
	m_pE1 = new KviLineEdit(this);
	m_pE2 = new KviLineEdit(this);
	m_pE3 = new KviLineEdit(this);
	g->addMultiCellWidget(m_pE1, 0, 0, 0, 1);
	g->addMultiCellWidget(m_pE2, 1, 1, 0, 1);
	g->addMultiCellWidget(m_pE3, 2, 2, 0, 1);

	KviPushButton *b;
	b = new KviPushButton("test", this, "mydialog_testbutton");
	connect(b, SIGNAL(clicked()), this, SLOT(btn_pressed()));
	g->addWidget(b, 3, 0);

	b = new KviPushButton("btn2", this, "mydialog_testbutton");
	connect(b, SIGNAL(clicked()), this, SLOT(btn2_pressed()));
	g->addWidget(b, 3, 1);
}

void MyDialog::btn_pressed()
{
	m_pWin->output(KVI_OUT_INTERNAL, "MYDIALOG: test");
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE1->text().utf8());
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE2->text().utf8());
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE3->text().utf8());
}

void MyDialog::btn2_pressed()
{
	m_pWin->output(KVI_OUT_INTERNAL, "MYDIALOG: button 2");
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE1->text().utf8());
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE2->text().utf8());
	m_pWin->output(KVI_OUT_INTERNAL, (const char *) m_pE3->text().utf8());
}

MyDialog::~MyDialog()
{
	// Nothing here
}

/**
 * This is a global in the plugin.
 */
MyDialog *d = 0;

/**
 * This is what the command MYDIALOG does.
 */
bool mydialog_plugin_command_mydialog(KviPluginCommandStruct *cmd)
{
	if( !d ) d = new MyDialog(cmd);
	d->show();
	return true;
}

/**
 * Init routine: registers the command MYDIALOG.
 */
bool mydialog_plugin_init(KviPluginCommandStruct *cmd)
{
	kvirc_plugin_register_command(cmd->handle, "MYDIALOG", mydialog_plugin_command_mydialog);
	return true;
}

/**
 * Cleanup routine: do not forget to delete the objects you have created :)
 */
void mydialog_plugin_cleanup()
{
	if( d ) {
		delete d;
		d = 0;
	}
}

/**
	@document: doc_plugin_mydialog.kvihelp
	@title: The KVIrc MyDialog plugin
		This plugin is for demonstration only. Its purpose is to show how to implement
		dialogs in plugins.<br>
		<docsubtitle>Note</docsubtitle>
		...<br>
		...<br>
		...<br>
*/

/**
 * Tells KVIrc where to find the help page.
 */
void mydialog_plugin_help()
{
	kvirc_plugin_show_help_page("doc_plugin_mydialog.kvihelp");
}

/**
 * Your plugin definition structure
 */
KviPlugin kvirc_plugin =
{
	"MyDialog",                             // Place the name of your plugin here. It should be the same as the library name.
	"My first KVIrc plugin (dialog)",       // Place a one line description of your plugin here.
	"0.1",                                  // Place the version of your plugin here.
	"Your Name <you@mailhost>",             // Place your name and email here.
	"<html>"
		"This plugin shows you how to use "
		"Qt dialogs in plugins...<br>"
		"It exports the <b>/MYDIALOG</b> command."
		"</html>",                          // Place a short description of what your plugin does here.
	mydialog_plugin_init,                   // Init routine
	mydialog_plugin_cleanup,                // Cleanup routine
	0,                                      // You have no configuration routine yet
	mydialog_plugin_help                    // This is the way to provide help for you plugin
};

#include "m_kvi_mydialog.moc"
